@@ -1,4 +1,4 @@
-# Copyright 2019 Wingify Software Pvt. Ltd.
+# Copyright 2019-2021 Wingify Software Pvt. Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,6 @@
 
 
 class OperatorTypes:
-    AND = 'and'
-    OR = 'or'
-    NOT = 'not'
+    AND = "and"
+    OR = "or"
+    NOT = "not"
